# py-handoff: Like Handoff, but in Python

## Usage
On each Windows/MacOS/Linux devices connected to the same LAN, run the following command:
```
    pip install py-handoff
    py-handoff
```
Now all you devices would share their clipboard.